@@ -187,10 +187,8 @@ class Job(SubDir):
                 .get_version(str(data["version"]))
             )
 
-    def delete(self, *, cleanup_orphans: bool = True):
+    def delete(self):
         if not self.exists():
             raise FileNotFoundError()
         self._cleanup_product_tree()
         self.root().rmtree(self._path)
-        if cleanup_orphans:
-            self.root().cleanup_orphan_blobs()
