@@ -204,7 +204,7 @@ class Tag(SubDir):
         elif path.is_file():
             path.unlink()
 
-    def delete(self, *, force: bool = False, cleanup_orphans: bool = True):
+    def delete(self, *, force: bool = False):
         if not self.exists():
             raise FileNotFoundError()
         if self.is_locked():
@@ -212,7 +212,5 @@ class Tag(SubDir):
         if not force and self.is_released():
             raise OSError(f"Tag {self.name} is released, use force")
         for j in self.get_jobs():
-            j.delete(cleanup_orphans=False)
+            j.delete()
         self.root().rmtree(self._path)
-        if cleanup_orphans:
-            self.root().cleanup_orphan_blobs()
